## Examples

* [BikeStandEndCap.py](BikeStandEndCap.py)
    -  Replace an oval cap lost from my bike repair stand.

* [CPAPStand.py](CPAPStand.py)
    -  Stand I use for a ResMed CPAP, should be easily tuned to other sized machines.

* [DupontConnectorCrimpHelper.py](DupontConnectorCrimpHelper.py)
    -  Accessories for iCrimp/IWISS SN58B and SN28B crimpers to make it easy to crimp Dupont connectors.

* [KnifeStand.py](KnifeStand.py)
    -  Knife Stand Example

* [LidHolder.py](LidHolder.py)
    -  Make a holder for multiple sizes of lids.

* [NeilMedDrainStandv1.py](NeilMedDrainStandv1.py)
    -  Drain stand for a NeilMed sinus rinse bottle.

* [NeilMedDrainStandv2.py](NeilMedDrainStandv2.py)
    -  Drain stand for a NeilMed sinus rinse bottle.

* [VacuumCPAPTools.py](VacuumCPAPTools.py)
    -  Attach CPAP hose to vacuum cleaner. For a Dyson, but could easily be adapted.

* [axes.py](axes.py)
    -  Axes ProjectBox Example

* [head_rest_purse_hanger.py](head_rest_purse_hanger.py)
    -  A purse hanger that uses you car's head rest posts.

* [kid_n_b.py](kid_n_b.py)
    -  Wrench, Nuts, Bolts, Pieces with Holes, for Kids.

* [kid_nail.py](kid_nail.py)
    -  Create two different sized "nails" that goes into holes on a kid's workbench.

* [name_plate.py](name_plate.py)
    -  Create a name plate from revolved text.

* [pbox_components.py](pbox_components.py)
    -  ProjectBox Example Components.

* [pbox_intercom.py](pbox_intercom.py)
    -  Intercom ProjectBox Example

